@@ -4,18 +4,15 @@
 #include <errno.h>
 #include <limits.h>
 #include <stdbool.h>
+#include <stdint.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
-#include <unistd.h>
 #include "str.h"
 #include "unicode.h"
 #include "util.h"
 
-char *strstr(const char *haystack, const char *needle);
-char *strerror(int errnum);
-
 static struct str *parse_section(struct parser *p) {
 	struct str *section = str_create();
 	uint32_t ch;
@@ -211,7 +208,9 @@ static void parse_text(struct parser *p) {
 			if (ch == UTF8_INVALID) {
 				parser_fatal(p, "Unexpected EOF");
 			} else if (ch == '\\') {
-				fprintf(p->output, "\\\\");
+				fprintf(p->output, "\\e");
+			} else if (ch == '`') {
+				fprintf(p->output, "\\`");
 			} else {
 				utf8_fputch(p->output, ch);
 			}
@@ -329,24 +328,12 @@ static int parse_indent(struct parser *p, int *indent, bool write) {
 }
 
 static void list_header(struct parser *p, int *num) {
-	fprintf(p->output, ".RS 4\n");
-	fprintf(p->output, ".ie n \\{\\\n");
-	if (*num == -1) {
-		fprintf(p->output, "\\h'-0%d'%s\\h'+03'\\c\n",
-				*num >= 10 ? 5 : 4, "\\(bu");
-	} else {
-		fprintf(p->output, "\\h'-0%d'%d.\\h'+03'\\c\n",
-				*num >= 10 ? 5 : 4, *num);
-	}
-	fprintf(p->output, ".\\}\n");
-	fprintf(p->output, ".el \\{\\\n");
 	if (*num == -1) {
 		fprintf(p->output, ".IP %s 4\n", "\\(bu");
 	} else {
 		fprintf(p->output, ".IP %d. 4\n", *num);
 		*num = *num + 1;
 	}
-	fprintf(p->output, ".\\}\n");
 }
 
 static void parse_list(struct parser *p, int *indent, int num) {
@@ -354,6 +341,7 @@ static void parse_list(struct parser *p, int *indent, int num) {
 	if ((ch = parser_getch(p)) != ' ') {
 		parser_fatal(p, "Expected space before start of list entry");
 	}
+	fprintf(p->output, ".PD 0\n");
 	list_header(p, &num);
 	parse_text(p);
 	do {
@@ -373,18 +361,15 @@ static void parse_list(struct parser *p, int *indent, int num) {
 			if ((ch = parser_getch(p)) != ' ') {
 				parser_fatal(p, "Expected space before start of list entry");
 			}
-			roff_macro(p, "RE", NULL);
 			list_header(p, &num);
 			parse_text(p);
 			break;
 		default:
-			fprintf(p->output, "\n");
+			roff_macro(p, "PD", NULL);
 			parser_pushch(p, ch);
-			goto ret;
+			return;
 		}
 	} while (ch != UTF8_INVALID);
-ret:
-	roff_macro(p, "RE", NULL);
 }
 
 static void parse_literal(struct parser *p, int *indent) {
@@ -736,7 +721,7 @@ static void parse_document(struct parser *p) {
 						p->fmt_line, p->fmt_col);
 				parser_fatal(p, error);
 			}
-			roff_macro(p, "P", NULL);
+			roff_macro(p, "PP", NULL);
 			break;
 		default:
 			parser_pushch(p, ch);
